.. spatialtis_core documentation master file, created by
   sphinx-quickstart on Tue Aug 24 10:27:43 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Documentation of spatialtis_core
===========================================

spatialtis_core implemented geometry manipulation and spatial analysis algorithms in Rust but comes with a Python API.
It's developed to be used by spatialtis. For regular spatial single-cell analysis, please use spatialtis.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   autoapi/index



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
